#!/bin/bash
# check_zap_pri.sh
# modified by alang 2010-3-11
#
#       install this into /usr/lib/nagios/plugins/contrib/
# You need a manager entry in /etc/asterisk/manager.conf
# [nagios]
# secret=somesecret
# deny=0.0.0.0/0.0.0.0
# permit=127.0.0.0/255.0.0.0
# permit=111.222.333.444/255.255.255.111 <-- the network nagios connects from
# read = system,call,log,verbose,command,agent,user
# write = system,call,log,verbose,command,agent,user
#
# add the following command to your commands.cfg
#
# define command{
#         command_name    check_zappri_mgr
#         command_line    /usr/lib/nagios/plugins/contrib/check_zappri_mgr $ARG1$ $ARG2$ $HOSTADDRESS$
#         }
#
# the services.cfg entry uses this check_command
# check_command              check_zappri_mgr!mgr_user!mgr_pass
#
# this is a basic Nagios plugin that tests ISDN lines status in Asterisk
PATH=/bin:/sbin:/usr/bin:/usr/sbin
FAILS=""
HOST=$3
USER=$1
PASS=$2
EOF="\015\012"
BLANK=$EOF$EOF
MAIL_TO="name@your.email.address"
MAIL_S="IP PBX Alert"

if [ ! $# -eq 3 ];then
   echo "Usage: `basename $0` [USER] [PASS] [HOST]"
   exit 1
fi

alert_email(){
  BODY="$1"
  echo "BODY=$BODY"
  #echo $BODY | mail -s $MAIL_S $MAIL_TO
}

check_ami_port(){
  #(echo "quit") | telnet $HOST 5038 | grep Connected > /dev/null 2>&1
  nc -w 1 $HOST 5038 >/dev/null 2>&1
  if [ "$?" -ne "0" ]; then #Not Ok
     echo -e "\nAbort!! Please check the AMI service(port 5038) on target host($HOST)."
     alert_email "Event: Abort!! Please check the AMI service(port 5038) on target host($HOST)."
     exit 1
  fi
}

check_login(){
  LOGIN=$((echo -ne "Action: Login$EOF"
  echo -ne "Username: $USER$EOF"
  echo -ne "Secret: $PASS$BLANK"
  echo -ne "Events: Off$EOF"
  echo -ne "Action: Logoff$BLANK") | nc $HOST 5038 | grep "Message")

  RESPONSE="$(echo $LOGIN | sed -e 's/
//' -e 's/Message: //')"
  if [ "$RESPONSE" = "Authentication failed" ]; then
     echo "Abort!! Authentication failed."
     alert_email "Event: Abort!! Authentication failed."
     exit 1
  fi
}

check_pri(){
  SPANS=$((echo -ne "Action: Login$EOF"
  echo -ne "Username: $USER$EOF"
  echo -ne "Secret: $PASS$BLANK"
  echo -ne "Action: Command$EOF"
  echo -ne "Command: pri show spans$BLANK"
  echo -ne "Action: Logoff$BLANK") | nc $HOST 5038 | grep -a PRI | awk '{print $3;}' | cut -d"/" -f1)

  for i in $SPANS; do
     STATUS=$((echo -ne "Action: Login$EOF"
     echo -ne "Username: $USER$EOF"
     echo -ne "Secret: $PASS$BLANK"
     echo -ne "Action: Command$EOF"
     echo -ne "Command: pri show span $i$BLANK"
     echo -ne "Action: Logoff$BLANK") | nc $HOST 5038 | grep -a Status | awk '{print $3;}' | cut -d, -f1)
     if [ $STATUS != "Up" ]; then
        FAILS="$FAILS span $i"
     fi
  done

  if [ "x$FAILS" != "x" ]; then
     echo "ISDN Critical: lines down, $FAILS"
     alert_email "Event: PRI lines down, $FAILS"
     exit 1
  fi
}

check_ami_port
check_login
check_pri


